==> com.liferay.app.builder.web-1.0.2.jar: META-INF/resources/js/pages/form-view/EditFormViewApp.es.js <==
Liferay.Loader.define("app-builder-web@1.0.2/js/pages/form-view/EditFormViewApp.es", ['module', 'exports', 'require', '@frontend-taglib-clay$clayui/modal', 'frontend-js-react-web$react', 'frontend-js-react-web$react-dnd', 'frontend-js-react-web$react-dnd-html5-backend', '../../AppContext.es', './EditFormView.es'], function (module, exports, require) {
  var define = undefined;
  Object.defineProperty(exports, "__esModule", {
    value: true
  });
  exports["default"] = _default;

  var _modal = require("@frontend-taglib-clay$clayui/modal");

  var _react = _interopRequireDefault(require("frontend-js-react-web$react"));

  var _reactDnd = require("frontend-js-react-web$react-dnd");

  var _reactDndHtml5Backend = _interopRequireDefault(require("frontend-js-react-web$react-dnd-html5-backend"));

  var _AppContext = require("../../AppContext.es");

  var _EditFormView = _interopRequireDefault(require("./EditFormView.es"));

  function _interopRequireDefault(obj) {
    return obj && obj.__esModule ? obj : { "default": obj };
  }

  function _objectWithoutProperties(source, excluded) {
    if (source == null) return {};var target = _objectWithoutPropertiesLoose(source, excluded);var key, i;if (Object.getOwnPropertySymbols) {
      var sourceSymbolKeys = Object.getOwnPropertySymbols(source);for (i = 0; i < sourceSymbolKeys.length; i++) {
        key = sourceSymbolKeys[i];if (excluded.indexOf(key) >= 0) continue;if (!Object.prototype.propertyIsEnumerable.call(source, key)) continue;target[key] = source[key];
      }
    }return target;
  }

  function _objectWithoutPropertiesLoose(source, excluded) {
    if (source == null) return {};var target = {};var sourceKeys = Object.keys(source);var key, i;for (i = 0; i < sourceKeys.length; i++) {
      key = sourceKeys[i];if (excluded.indexOf(key) >= 0) continue;target[key] = source[key];
    }return target;
  }

  var EditFormViewApp = (0, _reactDnd.DragDropContext)(_reactDndHtml5Backend["default"])(function (_ref) {
    var basePortletURL = _ref.basePortletURL,
        props = _objectWithoutProperties(_ref, ["basePortletURL"]);

    return _react["default"].createElement(_AppContext.AppContextProvider, {
      basePortletURL: basePortletURL
    }, _react["default"].createElement(_modal.ClayModalProvider, null, _react["default"].createElement(_EditFormView["default"], props)));
  });

  function _default(props) {
    return _react["default"].createElement(EditFormViewApp, props);
  }
  //# sourceMappingURL=EditFormViewApp.es.js.map
});
//# sourceMappingURL=EditFormViewApp.es.js.map

==> com.liferay.app.builder.web-1.0.18.jar: META-INF/resources/js/pages/form-view/EditFormViewApp.es.js <==
Liferay.Loader.define("app-builder-web@1.0.18/js/pages/form-view/EditFormViewApp.es", ['module', 'exports', 'require', '@frontend-taglib-clay$clayui/modal', 'frontend-js-react-web$react', '../../AppContext.es', '../../components/toast/ToastContext.es', './EditFormView.es'], function (module, exports, require) {
  var define = undefined;
  Object.defineProperty(exports, "__esModule", {
    value: true
  });
  exports["default"] = _default;

  var _modal = require("@frontend-taglib-clay$clayui/modal");

  var _react = _interopRequireDefault(require("frontend-js-react-web$react"));

  var _AppContext = require("../../AppContext.es");

  var _ToastContext = require("../../components/toast/ToastContext.es");

  var _EditFormView = _interopRequireDefault(require("./EditFormView.es"));

  function _interopRequireDefault(obj) {
    return obj && obj.__esModule ? obj : { "default": obj };
  }

  function _objectWithoutProperties(source, excluded) {
    if (source == null) return {};var target = _objectWithoutPropertiesLoose(source, excluded);var key, i;if (Object.getOwnPropertySymbols) {
      var sourceSymbolKeys = Object.getOwnPropertySymbols(source);for (i = 0; i < sourceSymbolKeys.length; i++) {
        key = sourceSymbolKeys[i];if (excluded.indexOf(key) >= 0) continue;if (!Object.prototype.propertyIsEnumerable.call(source, key)) continue;target[key] = source[key];
      }
    }return target;
  }

  function _objectWithoutPropertiesLoose(source, excluded) {
    if (source == null) return {};var target = {};var sourceKeys = Object.keys(source);var key, i;for (i = 0; i < sourceKeys.length; i++) {
      key = sourceKeys[i];if (excluded.indexOf(key) >= 0) continue;target[key] = source[key];
    }return target;
  }

  var EditFormViewApp = function EditFormViewApp(_ref) {
    var basePortletURL = _ref.basePortletURL,
        props = _objectWithoutProperties(_ref, ["basePortletURL"]);

    return _react["default"].createElement(_AppContext.AppContextProvider, {
      basePortletURL: basePortletURL
    }, _react["default"].createElement(_ToastContext.ToastContextProvider, null, _react["default"].createElement(_modal.ClayModalProvider, null, _react["default"].createElement(_EditFormView["default"], props))));
  };

  function _default(props) {
    return _react["default"].createElement(EditFormViewApp, props);
  }
  //# sourceMappingURL=EditFormViewApp.es.js.map
});
//# sourceMappingURL=EditFormViewApp.es.js.map
